@@ -26,7 +26,7 @@ constexpr auto URI = "org.kde.qmlkonsole";
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    
+
     KLocalizedString::setApplicationDomain("qmlkonsole");
     KAboutData aboutData(QStringLiteral("qmlkonsole"),
                          QStringLiteral("QMLKonsole"),
@@ -67,28 +67,34 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         util.setInitialWorkDir(std::move(initialWorkDir));
     }
 
-    qmlRegisterSingletonType<TerminalTabModel>(URI, 1, 0, "SavedCommandsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return SavedCommandsModel::self();
+    qmlRegisterSingletonType<SavedCommandsModel>(URI, 1, 0, "SavedCommandsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        const auto self = SavedCommandsModel::self();
+        QQmlEngine::setObjectOwnership(self, QQmlEngine::CppOwnership);
+        return self;
     });
     qmlRegisterSingletonType<TerminalTabModel>(URI, 1, 0, "TerminalTabModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return TerminalTabModel::self();
+        const auto self = TerminalTabModel::self();
+        QQmlEngine::setObjectOwnership(self, QQmlEngine::CppOwnership);
+        return self;
     });
     qmlRegisterSingletonType<FontListSearchModel>(URI, 1, 0, "FontListSearchModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return FontListSearchModel::self();
+        const auto self = FontListSearchModel::self();
+        QQmlEngine::setObjectOwnership(self, QQmlEngine::CppOwnership);
+        return self;
     });
     qmlRegisterSingletonInstance(URI, 1, 0, "Util", &util);
     qmlRegisterSingletonType(URI, 1, 0, "About", [](QQmlEngine *, QJSEngine *engine) {
         return engine->toScriptValue(KAboutData::applicationData());
     });
-    
+
     engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
-    
+
     // required for X11
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.qmlkonsole")));
-    
+
     return app.exec();
 }
